# Processamento de Imagem

O pacotede de processamento de imagem é usado para:<br />
	- Transferencia de histograma.<br />
	- Diferenciação de imagem.<br />
	- Redimencionamento de imagem.<br />
	- Plot de imagem.<br />
	- Plot de histograma.<br />
	- Plot de resultados.<br />
	- Salvar imagem.<br />
	- Carregar imagem.<br />

## Instalação

Use o pacote de instalação [pip](https://pip.pypa.io/en/stable/) para a instalação, por exemplo:

```bash
pip install processamento_de_imagem
```

## Autor
Jhonathan Alves

## Licença
[MIT](https://choosealicense.com/licenses/mit/)